.. Copyright 2013, 2014, 2015 Reahl Software Services (Pty) Ltd. All rights reserved.
 
Module reahl.web.interfaces
---------------------------

.. automodule:: reahl.web.interfaces


UserSessionProtocol
"""""""""""""""""""

.. autoclass:: UserSessionProtocol
   :members:

UserInputProtocol
"""""""""""""""""

.. autoclass:: UserInputProtocol
   :members:


PersistedExceptionProtocol
""""""""""""""""""""""""""

.. autoclass:: PersistedExceptionProtocol
   :members:


PersistedFileProtocol
"""""""""""""""""""""

.. autoclass:: PersistedFileProtocol
   :members:
